from django.utils.translation import gettext_lazy as tr
from django.apps import AppConfig


class ConcordiaConfig(AppConfig):
    name = 'concordia'
    verbose_name = tr('Concordia Sync')
